@@ -1243,6 +1243,16 @@ public:
         printToken(node, QStringLiteral("scalar"));
         if (node->commonScalar) printToken(node->commonScalar, QStringLiteral("commonScalar"), QStringLiteral("commonScalar"));
         if (node->constantOrClassConst) printToken(node->constantOrClassConst, QStringLiteral("constantOrClassConst"), QStringLiteral("constantOrClassConst"));
+        if (node->offsetItemSequence)
+        {
+            const KDevPG::ListNode<DimListItemAst*> *__it = node->offsetItemSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("dimListItem"), QStringLiteral("offsetItem[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
         if (node->encapsList) printToken(node->encapsList, QStringLiteral("encapsList"), QStringLiteral("encapsList"));
         if (node->stringIndex) printToken(node->stringIndex, QStringLiteral("stringIndexSpecifier"), QStringLiteral("stringIndex"));
         ++m_indent;
